@@ -14,9 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-readonly DOCS_CHANGES=`git diff --name-status master | grep "docs/" | wc -l`
+readonly DOCS_CHANGES=`git diff --name-status main | grep "docs/" | wc -l`
 
 if [ $DOCS_CHANGES -gt 0 ]; then
   echo "There are $DOCS_CHANGES changes in docs, testing site generation..."
   make build-docs-preview
-fi
\ No newline at end of file
+fi
