@@ -17,6 +17,7 @@ limitations under the License.
 package config
 
 import (
+	"context"
 	"fmt"
 	"io/ioutil"
 	"path/filepath"
@@ -26,11 +27,11 @@ import (
 
 	"github.com/imdario/mergo"
 	"github.com/mitchellh/go-homedir"
-	"github.com/sirupsen/logrus"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/cluster"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	kubectx "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/context"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/timeutil"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/yaml"
@@ -71,12 +72,12 @@ func readConfigFileCached(filename string) (*GlobalConfig, error) {
 		filenameOrDefault, err := ResolveConfigFile(filename)
 		if err != nil {
 			configFileErr = err
-			logrus.Warnf("Could not load global Skaffold defaults. Error resolving config file %q", filenameOrDefault)
+			log.Entry(context.TODO()).Warnf("Could not load global Skaffold defaults. Error resolving config file %q", filenameOrDefault)
 			return
 		}
 		configFile, configFileErr = ReadConfigFileNoCache(filenameOrDefault)
 		if configFileErr == nil {
-			logrus.Infof("Loaded Skaffold defaults from %q", filenameOrDefault)
+			log.Entry(context.TODO()).Infof("Loaded Skaffold defaults from %q", filenameOrDefault)
 		}
 	})
 	return configFile, configFileErr
@@ -99,12 +100,12 @@ func ResolveConfigFile(configFile string) (string, error) {
 func ReadConfigFileNoCache(configFile string) (*GlobalConfig, error) {
 	contents, err := ioutil.ReadFile(configFile)
 	if err != nil {
-		logrus.Warnf("Could not load global Skaffold defaults. Error encounter while reading file %q", configFile)
+		log.Entry(context.TODO()).Warnf("Could not load global Skaffold defaults. Error encounter while reading file %q", configFile)
 		return nil, fmt.Errorf("reading global config: %w", err)
 	}
 	config := GlobalConfig{}
 	if err := yaml.Unmarshal(contents, &config); err != nil {
-		logrus.Warnf("Could not load global Skaffold defaults. Error encounter while unmarshalling the contents of file %q", configFile)
+		log.Entry(context.TODO()).Warnf("Could not load global Skaffold defaults. Error encounter while unmarshalling the contents of file %q", configFile)
 		return nil, fmt.Errorf("unmarshalling global skaffold config: %w", err)
 	}
 	return &config, nil
@@ -142,7 +143,7 @@ func getConfigForKubeContextWithGlobalDefaults(cfg *GlobalConfig, kubeContext st
 	var mergedConfig ContextConfig
 	for _, contextCfg := range cfg.ContextConfigs {
 		if util.RegexEqual(contextCfg.Kubecontext, kubeContext) {
-			logrus.Debugf("found config for context %q", kubeContext)
+			log.Entry(context.TODO()).Debugf("found config for context %q", kubeContext)
 			mergedConfig = *contextCfg
 		}
 	}
@@ -169,7 +170,7 @@ func GetDefaultRepo(configFile string, cliValue *string) (string, error) {
 		return "", err
 	}
 	if cfg.DefaultRepo != "" {
-		logrus.Infof("Using default-repo=%s from config", cfg.DefaultRepo)
+		log.Entry(context.TODO()).Infof("Using default-repo=%s from config", cfg.DefaultRepo)
 	}
 	return cfg.DefaultRepo, nil
 }
@@ -180,7 +181,7 @@ func GetInsecureRegistries(configFile string) ([]string, error) {
 		return nil, err
 	}
 	if len(cfg.InsecureRegistries) > 0 {
-		logrus.Infof("Using insecure-registries=%v from config", cfg.InsecureRegistries)
+		log.Entry(context.TODO()).Infof("Using insecure-registries=%v from config", cfg.InsecureRegistries)
 	}
 	return cfg.InsecureRegistries, nil
 }
@@ -192,13 +193,13 @@ func GetDebugHelpersRegistry(configFile string) (string, error) {
 	}
 
 	if cfg.DebugHelpersRegistry != "" {
-		logrus.Infof("Using debug-helpers-registry=%s from config", cfg.DebugHelpersRegistry)
+		log.Entry(context.TODO()).Infof("Using debug-helpers-registry=%s from config", cfg.DebugHelpersRegistry)
 		return cfg.DebugHelpersRegistry, nil
 	}
 	return constants.DefaultDebugHelpersRegistry, nil
 }
 
-func GetCluster(configFile string, minikubeProfile string, detectMinikube bool) (Cluster, error) {
+func GetCluster(ctx context.Context, configFile string, minikubeProfile string, detectMinikube bool) (Cluster, error) {
 	cfg, err := GetConfigForCurrentKubectx(configFile)
 	if err != nil {
 		return Cluster{}, err
@@ -213,7 +214,7 @@ func GetCluster(configFile string, minikubeProfile string, detectMinikube bool)
 		local = true
 
 	case cfg.LocalCluster != nil:
-		logrus.Infof("Using local-cluster=%t from config", *cfg.LocalCluster)
+		log.Entry(context.TODO()).Infof("Using local-cluster=%t from config", *cfg.LocalCluster)
 		local = *cfg.LocalCluster
 
 	case kubeContext == constants.DefaultMinikubeContext ||
@@ -223,7 +224,7 @@ func GetCluster(configFile string, minikubeProfile string, detectMinikube bool)
 		local = true
 
 	case detectMinikube:
-		local = cluster.GetClient().IsMinikube(kubeContext)
+		local = cluster.GetClient().IsMinikube(ctx, kubeContext)
 
 	default:
 		local = false
