@@ -17,8 +17,6 @@ limitations under the License.
 package constants
 
 import (
-	"github.com/sirupsen/logrus"
-
 	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 )
 
@@ -36,9 +34,6 @@ const (
 	DevInit     = Phase("DevInit")
 	Cleanup     = Phase("Cleanup")
 
-	// DefaultLogLevel is the default global verbosity
-	DefaultLogLevel = logrus.WarnLevel
-
 	// DefaultDockerfilePath is the dockerfile path is given relative to the
 	// context directory
 	DefaultDockerfilePath = "Dockerfile"
@@ -61,9 +56,6 @@ const (
 	DefaultCacheFile   = "cache"
 	DefaultMetricFile  = "metrics"
 
-	DefaultRPCPort     = 50051
-	DefaultRPCHTTPPort = 50052
-
 	DefaultPortForwardAddress = "127.0.0.1"
 
 	DefaultProjectDescriptor = "project.toml"
